@@ -839,6 +839,20 @@ class RequestDataSms(NamedTuple):
     text: str
     """The text content of the SMS."""
 
+class RequestDataRest(NamedTuple):
+    """
+    Represents the data payload for an REST channel message.
+    """
+
+    sender: str
+    """The sender of the REST channel message."""
+
+    receiver: str
+    """The receiver of the REST channel message."""
+
+    text: str
+    """The text content of the REST channel message."""
+
 
 class RequestDataMessage(NamedTuple):
     """
@@ -860,8 +874,8 @@ class RequestDataMessage(NamedTuple):
     resource_id: int
     """Identifier for the resource being used in the message."""
 
-    message: Union[RequestDataSlack, RequestDataEmail, RequestDataSms]
-    """The message payload (Slack, Email, or SMS)."""
+    message: Union[RequestDataSlack, RequestDataEmail, RequestDataSms, RequestDataRest]
+    """The message payload (Slack, Email, SMS or REST)."""
 
 
 class ResponseDataSlack(NamedTuple):
@@ -970,6 +984,30 @@ class ResponseDataSms(NamedTuple):
         """Factory method to create a `ResponseDataSms` object."""
         return cls(sender, receiver, text)
 
+class ResponseDataRest(NamedTuple):
+    """
+    Represents the data payload for the response to a REST channel request.
+    """
+
+    sender: str
+    """The sender of the REST channel message."""
+
+    receiver: str
+    """The receiver of the REST channel message."""
+
+    text: str
+    """The text content of the REST channel message."""
+
+    @classmethod
+    def make(
+        cls,
+        sender: str,
+        receiver: str,
+        text: str
+    ) -> 'ResponseDataRest':
+        """Factory method to create a `ResponseDataRest` object."""
+        return cls(sender, receiver, text)
+
 
 class ResponseDataMessage(NamedTuple):
     """
@@ -985,8 +1023,8 @@ class ResponseDataMessage(NamedTuple):
     resource_id: int
     """Identifier for the resource being used in the message."""
 
-    message: Union[ResponseDataSlack, ResponseDataEmail, ResponseDataSms]
-    """The response message payload (Slack, Email, or SMS)."""
+    message: Union[ResponseDataSlack, ResponseDataEmail, ResponseDataSms, ResponseDataRest]
+    """The response message payload (Slack, Email, SMS or REST)."""
 
     ref_payload_id: Optional[str]
     """Reference to the original request payload."""
@@ -1005,7 +1043,7 @@ class ResponseDataMessage(NamedTuple):
         cls,
         instance_id: int,
         resource_id: int,
-        message: Union[ResponseDataSlack, ResponseDataEmail, ResponseDataSms],
+        message: Union[ResponseDataSlack, ResponseDataEmail, ResponseDataSms, ResponseDataRest],
         ref_payload_id: Optional[str] = None,
         translate_lang: Optional[str] = None,
         tone_shifting: Optional[str] = None,
